% BODE - Creates a bode plot of a transfer function
%
% USAGE
%
% bode(TF, w) plots a bode plot of TF, where TF is the transfer function as a 
% function of w and w is the frequency.  TF can be created using the TF
% function.
%
% Example: to produce the bode plot of H = 1/s from 0 to 1,000 radians per 
% second.
%
% w = 1:1000;
% h = tf([0 1], [1 0], w);
% bode(h, w);
%
% Licensed under the GPL
% Copyright (C) 2014 Jonathan Weaver <jonw0224@aim.com>

function [A] = bode(TF,w)

% This file is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.

    subplot(2,1,1);
    semilogx(w./2./pi, 20*log10(abs(TF)));
    title('Magnitude', 'fontsize', 14);
    ylabel('Gain (dB)');
    a = gca
    set(a, 'xminorgrid','on');
    grid on;

    subplot(2,1,2);
    semilogx(w./2./pi, angle(TF));
    title('Phase', 'fontsize', 14);
    ylabel('Angle (Radians)');
    xlabel('Frequency (Hz)');
    a = gca
    set(a, 'xminorgrid','on');
    grid on;
end
    