% TF - creates a transfer function
% 
% USAGE
%
% h = tf(N, D, w) returns the transfer function as a function of w where N is a
% vector of coefficients for the numerator and D is a vector of coefficents 
% for the denominator and w is a vector of radial frequency to evaluate the
% transfer function
% 
% For the transfer function H = (s^2 + 1) / (s^2 + s + 1) evaluated between 1 
% and 1000 radians per second then
% 
% N = [1 0 1];
% D = [1 1 1];
% w = 1:1000;
% h = tf(N,D,w);
%
% Licensed under the GPL
% Copyright (C) 2014 Jonathan Weaver <jonw0224@aim.com>

function [TF] = tf(N, D, w)

% This file is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.

    jw = j.*w;
    if size(N) == size(D)
        a = size(D);
        if(a(1) == 1)
            Wv = jw.^0;
            for i = 2:a(2)
                Wv = [jw.^(i-1); Wv];
            end
            TF = (N*Wv)./(D*Wv);
        else
            error('N and D should be column vectors');
        end
    else
        error('N and D should be the same size');
    end
end